Module body

Module body 

HTTP body types.

body types are generic over Body trait and mutation of body type must also implement said trait for being accepted as body type that xitca-http know of.

Structs

BoxBody
type erased body. This is a !Send box, unlike http_body_util::UnsyncBoxBody.
Data
Either
Empty
Full
A body that consists of a single chunk.
ResponseBody
A unified response body type. Generic type is for custom pinned response body(type implement Body).
StreamBody
Bidirectional adapter between Stream and Body at the Frame level:
StreamDataBody
Bidirectional adapter between Stream and Body:
Trailers

Enums

Frame
RequestBody
A unified request body type for different http protocols. This enables one service type to handle multiple http protocols.
SizeHint
Size hint for type impl Body trait

Traits

Body
An asynchronous streaming body composed of Frames.
BodyExt