pub enum RequestBody {
Boxed(BoxBody),
None,
}Expand description
A unified request body type for different http protocols. This enables one service type to handle multiple http protocols.
Variants
Implementations
Sourceimpl RequestBody
impl RequestBody
pub fn into_boxed(self) -> BoxBody