pub trait BufInterest {
// Required methods
fn want_write_buf(&self) -> bool;
fn want_write_io(&self) -> bool;
}Expand description
trait generic over different types of buffer strategy.
Required Methods
Sourcefn want_write_buf(&self) -> bool
fn want_write_buf(&self) -> bool
flag if buffer want more data to be filled in.
Sourcefn want_write_io(&self) -> bool
fn want_write_io(&self) -> bool
flag if buffer want to write data to io.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".