HTTP body types.
body types are generic over Body trait and mutation of body type must also implement said trait for being accepted as body type that xitca-http know of.
Structs
- BoxBody
- type erased body. This is a
!Sendbox, unlikehttp_body_util::UnsyncBoxBody. - Data
- Either
- Empty
- Full
- A body that consists of a single chunk.
- Response
Body - A unified response body type. Generic type is for custom pinned response body(type implement Body).
- Stream
Body - Bidirectional adapter between
StreamandBodyat theFramelevel: - Stream
Data Body - Bidirectional adapter between
StreamandBody: - Trailers
Enums
- Frame
- Request
Body - A unified request body type for different http protocols. This enables one service type to handle multiple http protocols.
- Size
Hint - Size hint for type impl
Bodytrait